/*
 * Copyright (c) 2009 Mysema Ltd.
 * All rights reserved.
 * 
 */
package com.mysema.commons.web;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.mysema.commons.lang.URIUtil;

/**
 * URIUtil provides
 * 
 * @author tiwe
 * @version $Id$
 */
public final class ContextURL {
	
	private ContextURL(){}

    public static boolean isContextRoot(HttpServletRequest request, String url){
        String contextRoot = request.getContextPath();
        if (contextRoot.equals("/")){
        	return url.equals("/");
        }else{
        	return url.equals(contextRoot) || url.equals(contextRoot +"/");
        }        
    }
    
    public static String resolve(HttpServletRequest request, String url) {
        if (URIUtil.isAbsoluteURL(url)) {
            return url;
        } else if (url.startsWith("/")){
            String context = request.getContextPath();
            if ("/".equals(context)){
                return url;
            }else{
                return context + url;
            }
        }else{
        	return url;
        }
    }
    
    public static String resolve(HttpServletRequest request, HttpServletResponse response, String url, boolean absolute, boolean secure){
    	StringBuilder builder = new StringBuilder();
        // make the path absolute if absolute is set or HTTP -> HTTPS is needed
        if (absolute || (secure && !request.isSecure())) {
            // URI schema
            builder.append(secure || request.isSecure() ? "https://" : "http://");
            builder.append(request.getServerName());
            // print port, if port != 80 && port != 443
            if (request.getServerPort() != 80 && request.getServerPort() != 443) {
                if (secure && !request.isSecure()) {
                    builder.append(":").append(request.getServerPort() + 363);
                } else {
                    builder.append(":").append(request.getServerPort());
                }
            }
        }
        builder.append(request.getContextPath());
        builder.append(response.encodeURL(url));
        return builder.toString();
    }



}
